import unittest
from mastercardapicore import RequestMap, Config, OAuthAuthentication
from os.path import dirname, realpath, join

class BaseTest(unittest.TestCase):
	responses = {}
	authentications = {
		"default": OAuthAuthentication("L5BsiPgaF-O3qA36znUATgQXwJB6MRoMSdhjd7wt50c97279!50596e52466e3966546d434b7354584c4975693238513d3d", join(dirname(realpath(__file__)),"resources", "mcapi_sandbox_key.p12"), "test", "password"),
		"send_1": OAuthAuthentication("-mzBAF1UFssV7H1VDrJuXQ45AZlkmfNEoMUxocsGae1f9f59!cba9cef300b64e3e812698fd7a8b6bff0000000000000000", join(dirname(realpath(__file__)),"resources", "send_sdk_ci_1_sandbox.p12"), "keyalias", "keystorepassword"),
		"send_2": OAuthAuthentication("3nSpMB_IjYzyLhUbK37cHsYHVy7b3goCk1Q1DEinb60951d6!1b1af7c5aa1a4d5792ee9e707f9b87d60000000000000000", join(dirname(realpath(__file__)),"resources", "send_sdk_ci_2_sandbox.p12"), "keyalias", "keystorepassword"),
		"send_3": OAuthAuthentication("qPG4eNdxSW2pT1M5YdsyBoQs1CeyYmQ2JvYL2qq_a2b027f3!c6350fb087cc4df58700e117636e16c90000000000000000", join(dirname(realpath(__file__)),"resources", "send_sdk_ci_3_sandbox.p12"), "keyalias", "keystorepassword"),
		
	}

	@staticmethod
	def putResponse(name,response):
		BaseTest.responses[name] = response

	@staticmethod
	def resolveResponseValue(overrideValue):
		pos = overrideValue.find('.')

		name = overrideValue[:pos]
		#print "Example Name: %s" % name
		key = overrideValue[pos+1:]
		#print "Key Name: %s" % key


		if name in BaseTest.responses:
			response = BaseTest.responses[name]
			if response.containsKey(key) == True:
				return str(response.get(key))
			else:
				print "Key:'%s' is not found in the response" % key
		else:
			print "Example:'%s' is not found in the response" % name

		return None

	def customAssertEqual(self,ignoreAsserts,key, actualValue, expectedValue):
		if (key not in ignoreAsserts):
			self.customAssertValue(expectedValue,actualValue)

	def customAssertValue(self,expected,actual):
		if (isinstance(actual,float)):
			self.assertEqual(float(expected), actual)
		else:
			self.assertEqual(expected.lower(), str(actual).lower())

	def setAuthentication(self, keyId):
		authentication = self.authentications[keyId]

		if authentication is None:
			raise Exception("No authentication found for keyId: " + keyId)

		Config.setAuthentication(authentication)

	def resetAuthentication(self):
		self.setAuthentication("default")


from mastercardapicore import *
from mastercardmatch.addterminatedmerchant import *
from mastercardmatch.retroactiveinquiryrequest import *
from mastercardmatch.acquirercontactrequest import *
from mastercardmatch.sdkconfig import *
from mastercardmatch.retroactiveinquirydetailsrequest import *
from mastercardmatch.terminationinquiryrequest import *
from mastercardmatch.terminationinquiryhistoryrequest import *



#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#

import unittest
import time
from mastercardapicore import RequestMap
from base_test import BaseTest
from mastercardmatch import *


class AddTerminatedMerchantTest(BaseTest):

    def setUp(self):
        Config.setDebug(True)
        self.resetAuthentication()

    
        
                
    def test_example_add_terminated_merchant(self):
        

        
    
        map = RequestMap()
        map.set("AddMerchantRequest.AcquirerId", "1996")
        map.set("AddMerchantRequest.Merchant.Name", "TEST TECHMERCHANT1")
        map.set("AddMerchantRequest.Merchant.DoingBusinessAsName", "TEST TECHMERCHANT1")
        map.set("AddMerchantRequest.Merchant.MerchantId", "057049905280645")
        map.set("AddMerchantRequest.Merchant.MerchantCategory", "0742")
        map.set("AddMerchantRequest.Merchant.Address.Line1", "6700 Ben Nevis")
        map.set("AddMerchantRequest.Merchant.Address.Line2", "")
        map.set("AddMerchantRequest.Merchant.Address.City", "GLASGOW")
        map.set("AddMerchantRequest.Merchant.Address.Province", "")
        map.set("AddMerchantRequest.Merchant.Address.CountrySubdivision", "MA")
        map.set("AddMerchantRequest.Merchant.Address.PostalCode", "93137")
        map.set("AddMerchantRequest.Merchant.Address.Country", "USA")
        map.set("AddMerchantRequest.Merchant.PhoneNumber", "5675542210")
        map.set("AddMerchantRequest.Merchant.AltPhoneNumber", "5672655441")
        map.set("AddMerchantRequest.Merchant.NationalTaxId", "56733")
        map.set("AddMerchantRequest.Merchant.CountrySubdivisionTaxId", "37354")
        map.set("AddMerchantRequest.Merchant.CATFlag", "N")
        map.set("AddMerchantRequest.Merchant.DateOpened", "04/12/2009")
        map.set("AddMerchantRequest.Merchant.DateClosed", "03/19/2013")
        map.set("AddMerchantRequest.Merchant.ServiceProvLegal", "TEST SVC PRVDER")
        map.set("AddMerchantRequest.Merchant.ServiceProvDBA", "JNL ASSOC")
        map.set("AddMerchantRequest.Merchant.Url[0]", "www.testjj.com")
        map.set("AddMerchantRequest.Merchant.Url[1]", "www.jnltestjj.com")
        map.set("AddMerchantRequest.Merchant.Principal.FirstName", "PAUL")
        map.set("AddMerchantRequest.Merchant.Principal.LastName", "HEMINGHOFF")
        map.set("AddMerchantRequest.Merchant.Principal.MiddleInitial", "L")
        map.set("AddMerchantRequest.Merchant.Principal.Address.Line1", "2200 Shepley Drive")
        map.set("AddMerchantRequest.Merchant.Principal.Address.Line2", "SUITE 789")
        map.set("AddMerchantRequest.Merchant.Principal.Address.City", "BROWNSVILLE")
        map.set("AddMerchantRequest.Merchant.Principal.Address.Province", "")
        map.set("AddMerchantRequest.Merchant.Principal.Address.CountrySubdivision", "MO")
        map.set("AddMerchantRequest.Merchant.Principal.Address.PostalCode", "89022")
        map.set("AddMerchantRequest.Merchant.Principal.Address.Country", "USA")
        map.set("AddMerchantRequest.Merchant.Principal.PhoneNumber", "3906541234")
        map.set("AddMerchantRequest.Merchant.Principal.AltPhoneNumber", "4567390234")
        map.set("AddMerchantRequest.Merchant.Principal.NationalId", "123456789")
        map.set("AddMerchantRequest.Merchant.Principal.DriversLicense.Number", "3K33094")
        map.set("AddMerchantRequest.Merchant.Principal.DriversLicense.CountrySubdivision", "MS")
        map.set("AddMerchantRequest.Merchant.Principal.DriversLicense.Country", "USA")
        map.set("AddMerchantRequest.Merchant.ReasonCode", "04")
        map.set("AddMerchantRequest.Merchant.Comments", "Added for test reasons")
        
        
        response = AddTerminatedMerchant.create(map)

        ignoreAsserts = []
        
        

        BaseTest.putResponse("example_add_terminated_merchant", response)
        

    
        
        
        
        
        
        
    

if __name__ == '__main__':
    unittest.main()




#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from mastercardapicore.core.model import BaseObject
from mastercardapicore.core.model import RequestMap
from mastercardapicore.core.model import OperationConfig
from mastercardapicore.core.model import OperationMetadata
from sdkconfig import SDKConfig


class RetroactiveInquiryRequest(BaseObject):
    """
    
    """

    __config = {
        "f1ebd5ef-9e7c-4e1e-b730-81264e5882ff" : OperationConfig("/fraud/merchant/v3/retro/retro-list", "create", [], []),
        
    }

    def getOperationConfig(self,operationUUID):
        if operationUUID not in self.__config:
            raise Exception("Invalid operationUUID: "+operationUUI)

        return self.__config[operationUUID]

    def getOperationMetadata(self):
        return OperationMetadata(SDKConfig.getVersion(), SDKConfig.getHost())

    @classmethod
    def create(cls,mapObj):
        """
        Creates object of type RetroactiveInquiryRequest

        @param Dict mapObj, containing the required parameters to create a new object
        @return RetroactiveInquiryRequest of the response of created instance.
        """
        return BaseObject.execute("f1ebd5ef-9e7c-4e1e-b730-81264e5882ff", RetroactiveInquiryRequest(mapObj))










#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#

import unittest
import time
from mastercardapicore import RequestMap
from base_test import BaseTest
from mastercardmatch import *


class AcquirerContactRequestTest(BaseTest):

    def setUp(self):
        Config.setDebug(True)
        self.resetAuthentication()

    
        
                
    def test_example_contact_details(self):
        

        
    
        map = RequestMap()
        map.set("ContactRequest.AcquirerId", "12086")
        
        
        response = AcquirerContactRequest.create(map)

        ignoreAsserts = []
        
        

        BaseTest.putResponse("example_contact_details", response)
        

    
        
        
        
        
        
        
    

if __name__ == '__main__':
    unittest.main()




#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#

import unittest
import time
from mastercardapicore import RequestMap
from base_test import BaseTest
from mastercardmatch import *


class TerminationInquiryRequestTest(BaseTest):

    def setUp(self):
        Config.setDebug(True)
        self.resetAuthentication()

    
        
                
    def test_example_termination_inquiry(self):
        

        
    
        map = RequestMap()
        map.set("PageOffset", "0")
        map.set("PageLength", "10")
        map.set("TerminationInquiryRequest.AcquirerId", "1996")
        map.set("TerminationInquiryRequest.Merchant.Name", "XYZTEST  XYZTECHMERCHANT")
        map.set("TerminationInquiryRequest.Merchant.DoingBusinessAsName", "XYZTEST  XYZTECHMERCHANT")
        map.set("TerminationInquiryRequest.Merchant.AltPhoneNumber", "3098876333")
        map.set("TerminationInquiryRequest.Merchant.Address.Line1", "88 Nounce World")
        map.set("TerminationInquiryRequest.Merchant.Address.Line2", "APT 9009")
        map.set("TerminationInquiryRequest.Merchant.Address.City", "MICKENVINCE")
        map.set("TerminationInquiryRequest.Merchant.Address.CountrySubdivision", "MO")
        map.set("TerminationInquiryRequest.Merchant.Address.PostalCode", "66559")
        map.set("TerminationInquiryRequest.Merchant.Address.Country", "USA")
        map.set("TerminationInquiryRequest.Merchant.ServiceProvLegal", "JJC WORKSHIRE")
        map.set("TerminationInquiryRequest.Merchant.Principal.FirstName", "PRINCE")
        map.set("TerminationInquiryRequest.Merchant.Principal.LastName", "HENREY")
        map.set("TerminationInquiryRequest.Merchant.Principal.PhoneNumber", "9983339923")
        map.set("TerminationInquiryRequest.Merchant.Principal.AltPhoneNumber", "6365689336")
        map.set("TerminationInquiryRequest.Merchant.Principal.Address.CountrySubdivision", "IL")
        map.set("TerminationInquiryRequest.Merchant.Principal.Address.PostalCode", "66579")
        map.set("TerminationInquiryRequest.Merchant.Principal.Address.Country", "USA")
        map.set("TerminationInquiryRequest.Merchant.SearchCriteria.SearchAll", "Y")
        map.set("TerminationInquiryRequest.Merchant.SearchCriteria.MinPossibleMatchCount", "1")
        
        
        response = TerminationInquiryRequest.create(map)

        ignoreAsserts = []
        
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PageOffset", response.get("TerminationInquiry.PageOffset"),"0")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TotalLength", response.get("TerminationInquiry.PossibleMerchantMatches[0].TotalLength"),"14")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Name", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Name"),"XYZTEST  XYZTECHMERCHANT")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.DoingBusinessAsName", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.DoingBusinessAsName"),"XYZTEST  XYZTECHMERCHANT")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.AddedByAcquirerID", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.AddedByAcquirerID"),"1996")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.AddedOnDate", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.AddedOnDate"),"10/13/2015")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.PhoneNumber", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.PhoneNumber"),"5675543210")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.AltPhoneNumber", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.AltPhoneNumber"),"5672655441")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Address.Line1", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Address.Line1"),"6700 BEN NEVIS")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Address.City", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Address.City"),"GLASGOW")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Address.CountrySubdivision", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Address.CountrySubdivision"),"MA")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Address.PostalCode", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Address.PostalCode"),"93137")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Address.Country", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Address.Country"),"USA")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.CountrySubdivisionTaxId", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.CountrySubdivisionTaxId"),"*****")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.NationalTaxId", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.NationalTaxId"),"*****")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.ServiceProvLegal", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.ServiceProvLegal"),"TESTXYZ SVC PRVDER")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.ServiceProvDBA", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.ServiceProvDBA"),"JNL ASSOC")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].FirstName", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].FirstName"),"PAUL")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].LastName", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].LastName"),"HEMINGHOFF")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].NationalId", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].NationalId"),"*****")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].PhoneNumber", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].PhoneNumber"),"3906541234")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].AltPhoneNumber", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].AltPhoneNumber"),"4567390234")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].Address.Line1", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].Address.Line1"),"2200 SHEPLEY DRIVE")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].Address.Line2", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].Address.Line2"),"SUITE 789")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].Address.City", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].Address.City"),"BROWNSVILLE")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].Address.CountrySubdivision", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].Address.CountrySubdivision"),"MO")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].Address.PostalCode", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].Address.PostalCode"),"89022")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].Address.Country", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].Address.Country"),"USA")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].DriversLicense.Number", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].DriversLicense.Number"),"*****")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].DriversLicense.CountrySubdivision", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].DriversLicense.CountrySubdivision"),"MS")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].DriversLicense.Country", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.Principal[0].DriversLicense.Country"),"USA")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.UrlGroup[0].NoMatchUrls.Url[0]", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.UrlGroup[0].NoMatchUrls.Url[0]"),"WWW.TESTJJ.COM")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.UrlGroup[0].NoMatchUrls.Url[1]", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.UrlGroup[0].NoMatchUrls.Url[1]"),"WWW.JNLTESTJJ.COM")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.TerminationReasonCode", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].Merchant.TerminationReasonCode"),"04")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.Name", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.Name"),"M01")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.DoingBusinessAsName", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.DoingBusinessAsName"),"M02")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.Address", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.Address"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.PhoneNumber", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.PhoneNumber"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.AltPhoneNumber", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.AltPhoneNumber"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.CountrySubdivisionTaxId", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.CountrySubdivisionTaxId"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.NationalTaxId", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.NationalTaxId"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.ServiceProvLegal", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.ServiceProvLegal"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.ServiceProvDBA", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.ServiceProvDBA"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.PrincipalMatch[0].Name", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.PrincipalMatch[0].Name"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.PrincipalMatch[0].Address", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.PrincipalMatch[0].Address"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.PrincipalMatch[0].PhoneNumber", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.PrincipalMatch[0].PhoneNumber"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.PrincipalMatch[0].AltPhoneNumber", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.PrincipalMatch[0].AltPhoneNumber"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.PrincipalMatch[0].NationalId", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.PrincipalMatch[0].NationalId"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.PrincipalMatch[0].DriversLicense", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[0].MerchantMatch.PrincipalMatch[0].DriversLicense"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Name", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Name"),"XYZTEST  XYZTECHMERCHANT")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.DoingBusinessAsName", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.DoingBusinessAsName"),"XYZTEST  XYZTECHMERCHANT")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.AddedByAcquirerID", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.AddedByAcquirerID"),"1996")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.AddedOnDate", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.AddedOnDate"),"01/20/2016")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.PhoneNumber", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.PhoneNumber"),"5675543210")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.AltPhoneNumber", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.AltPhoneNumber"),"5672655441")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Address.Line1", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Address.Line1"),"6700 BEN NEVIS")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Address.City", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Address.City"),"GLASGOW")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Address.CountrySubdivision", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Address.CountrySubdivision"),"MA")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Address.PostalCode", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Address.PostalCode"),"93137")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Address.Country", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Address.Country"),"USA")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.CountrySubdivisionTaxId", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.CountrySubdivisionTaxId"),"*****")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.NationalTaxId", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.NationalTaxId"),"*****")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.ServiceProvLegal", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.ServiceProvLegal"),"TESTXYZ SVC PRVDER")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.ServiceProvDBA", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.ServiceProvDBA"),"JNL ASSOC")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].FirstName", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].FirstName"),"PAUL")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].LastName", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].LastName"),"HEMINGHOFF")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].NationalId", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].NationalId"),"*****")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].PhoneNumber", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].PhoneNumber"),"3906541234")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].AltPhoneNumber", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].AltPhoneNumber"),"4567390234")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].Address.Line1", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].Address.Line1"),"2200 SHEPLEY DRIVE")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].Address.Line2", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].Address.Line2"),"SUITE 789")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].Address.City", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].Address.City"),"BROWNSVILLE")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].Address.CountrySubdivision", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].Address.CountrySubdivision"),"MO")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].Address.PostalCode", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].Address.PostalCode"),"89022")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].Address.Country", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].Address.Country"),"USA")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].DriversLicense.Number", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].DriversLicense.Number"),"*****")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].DriversLicense.CountrySubdivision", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].DriversLicense.CountrySubdivision"),"MS")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].DriversLicense.Country", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.Principal[0].DriversLicense.Country"),"USA")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.UrlGroup[0].NoMatchUrls.Url[0]", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.UrlGroup[0].NoMatchUrls.Url[0]"),"WWW.TESTJJ.COM")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.UrlGroup[0].NoMatchUrls.Url[1]", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.UrlGroup[0].NoMatchUrls.Url[1]"),"WWW.JNLTESTJJ.COM")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.TerminationReasonCode", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].Merchant.TerminationReasonCode"),"04")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.Name", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.Name"),"M01")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.DoingBusinessAsName", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.DoingBusinessAsName"),"M02")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.Address", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.Address"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.PhoneNumber", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.PhoneNumber"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.AltPhoneNumber", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.AltPhoneNumber"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.CountrySubdivisionTaxId", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.CountrySubdivisionTaxId"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.NationalTaxId", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.NationalTaxId"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.ServiceProvLegal", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.ServiceProvLegal"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.ServiceProvDBA", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.ServiceProvDBA"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.PrincipalMatch[0].Name", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.PrincipalMatch[0].Name"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.PrincipalMatch[0].Address", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.PrincipalMatch[0].Address"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.PrincipalMatch[0].PhoneNumber", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.PrincipalMatch[0].PhoneNumber"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.PrincipalMatch[0].AltPhoneNumber", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.PrincipalMatch[0].AltPhoneNumber"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.PrincipalMatch[0].NationalId", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.PrincipalMatch[0].NationalId"),"M00")
        self.customAssertEqual(ignoreAsserts, "TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.PrincipalMatch[0].DriversLicense", response.get("TerminationInquiry.PossibleMerchantMatches[0].TerminatedMerchant[1].MerchantMatch.PrincipalMatch[0].DriversLicense"),"M00")
        

        BaseTest.putResponse("example_termination_inquiry", response)
        

    
        
        
        
        
        
        
    

if __name__ == '__main__':
    unittest.main()

